#
# spec file for package openstack-keystone
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global with_doc 1
%global sname keystone
%if 0%{?rhel} || 0%{?fedora}
%global rdo 1
%endif
Name:           openstack-keystone
Version:        11.0.0.0~xbeta2
Release:        5.1
Summary:        OpenStack Identity Service
License:        Apache-2.0
Group:          Applications/System
Url:            https://launchpad.net/keystone
Source0:        http://tarballs.openstack.org/%{sname}/%{sname}-11.0.0.0b2.tar.gz
Source1:        openstack-keystone.logrotate
Source2:        openstack-keystone.sysctl
Source3:        openstack-keystone.tmpfiles
Source4:        openstack-keystone.defaultconf
Source5:        openstack-keystone.README.config
BuildRequires:  openstack-macros
BuildRequires:  openstack-tempest
BuildRequires:  python-WebTest
BuildRequires:  python-devel
BuildRequires:  python-fixtures
BuildRequires:  python-freezegun
BuildRequires:  python-lxml
BuildRequires:  python-mock
BuildRequires:  python-os-api-ref
BuildRequires:  python-os-testr
BuildRequires:  python-oslo.cache
BuildRequires:  python-oslo.config
BuildRequires:  python-oslotest
BuildRequires:  python-osprofiler
BuildRequires:  python-pbr
BuildRequires:  python-python-subunit
BuildRequires:  python-reno
BuildRequires:  python-requests
BuildRequires:  python-testrepository
BuildRequires:  python-testresources
BuildRequires:  python-testtools
Requires:       python-%{sname} = %{version}-%{release}
BuildArch:      noarch
%if 0%{?suse_version}
BuildRequires:  libxmlsec1-openssl1
Requires(pre):  pwdutils
%endif
%if 0%{?rdo}
BuildRequires:  xmlsec1-openssl
Requires(pre):  shadow-utils
%endif

%description
Keystone is a Python implementation of the OpenStack
(http://www.openstack.org) identity service API.
.
This package contains the keystone python libraries.

%package -n     python-%{sname}
Summary:        Keystone Python libraries
Group:          Applications/System
Requires:       python-Babel
Requires:       python-Paste
Requires:       python-PasteDeploy
Requires:       python-PyMySQL
Requires:       python-Routes
Requires:       python-SQLAlchemy
Requires:       python-WebOb
Requires:       python-cryptography
Requires:       python-dogpile.cache
Requires:       python-jsonschema
Requires:       python-keystoneclient
Requires:       python-keystonemiddleware
Requires:       python-ldappool
Requires:       python-msgpack-python
Requires:       python-oauthlib
Requires:       python-oslo.cache
Requires:       python-oslo.concurrency
Requires:       python-oslo.config
Requires:       python-oslo.context
Requires:       python-oslo.db
Requires:       python-oslo.i18n
Requires:       python-oslo.log
Requires:       python-oslo.messaging
Requires:       python-oslo.middleware
Requires:       python-oslo.policy
Requires:       python-oslo.serialization
Requires:       python-oslo.utils
Requires:       python-osprofiler
Requires:       python-passlib
Requires:       python-pbr
Requires:       python-pycadf
Requires:       python-pysaml2
Requires:       python-python-memcached
Requires:       python-six
Requires:       python-sqlalchemy-migrate
Requires:       python-stevedore
%if 0%{?suse_version}
Requires:       python-pyldap
%endif
%if 0%{?rdo}
Requires:       python-ldap
%endif

%description -n   python-%{sname}
Keystone is a Python implementation of the OpenStack
(http://docs.openstack.org/developer/keystone/) identity service API.
This package contains the Keystone Python library.

%if 0%{?with_doc}
%package doc
Summary:        Documentation for OpenStack Identity Service
Group:          Documentation
BuildRequires:  python-PasteDeploy
BuildRequires:  python-Routes
BuildRequires:  python-Sphinx
BuildRequires:  python-cryptography
BuildRequires:  python-dogpile.cache
BuildRequires:  python-jsonschema
BuildRequires:  python-keystonemiddleware
BuildRequires:  python-ldappool
BuildRequires:  python-msgpack-python
BuildRequires:  python-oauthlib
BuildRequires:  python-oslo.concurrency
BuildRequires:  python-oslo.db
BuildRequires:  python-oslo.i18n
BuildRequires:  python-oslo.log
BuildRequires:  python-oslo.messaging
BuildRequires:  python-oslo.middleware
BuildRequires:  python-oslo.policy
BuildRequires:  python-oslosphinx
BuildRequires:  python-passlib
BuildRequires:  python-pysaml2
BuildRequires:  python-python-memcached

%description doc
OpenStack Keystone documentaion.
.
This package contains the documentation
%endif

%prep
%autosetup -n %{sname}-11.0.0.0b2
%if 0%{?rdo}
find . \( -name .gitignore -o -name .placeholder \) -delete
find keystone -name \*.py -exec sed -i '/\/usr\/bin\/env python/d' {} \;
# adjust paths to WSGI scripts
sed -i 's#/local/bin#/bin#' httpd/wsgi-keystone.conf
sed -i 's#apache2#httpd#' httpd/wsgi-keystone.conf
%endif

%build
%{py2_build}
export PYTHONPATH="."
%if 0%{?with_doc}
# docs generation requires everything to be installed first
pushd doc
make html
make man
popd
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}
%endif
# config file generation
oslo-config-generator --config-file config-generator/keystone.conf \
--output-file etc/keystone.conf.sample

%install
%{py2_install}
mkdir -p %{buildroot}%{_mandir}/man1
install -d -m 755 %{buildroot}%{_sysconfdir}/keystone
install -d -m 755 %{buildroot}%{_sysconfdir}/sysctl.d
install -d -m 755 %{buildroot}%{_localstatedir}/{lib,log}/keystone
install -d -m 750 %{buildroot}%{_localstatedir}/cache/keystone
install -d -m 755 %{buildroot}%{_sysconfdir}/keystone/keystone.conf.d/
# default dir for fernet tokens
install -d -m 750 %{buildroot}%{_sysconfdir}/keystone/credential-keys/
install -D -m 644 %{SOURCE3} %{buildroot}/%{_tmpfilesdir}/keystone.conf
install -p -D -m 640 etc/keystone.conf.sample %{buildroot}%{_sysconfdir}/keystone/keystone.conf
install -D -m 640 %{SOURCE4} %{buildroot}/%{_sysconfdir}/keystone/keystone.conf.d/010-keystone.conf
install -D -m 440 %{SOURCE5} %{buildroot}/%{_sysconfdir}/keystone/README.config
install -p -D -m 640 etc/logging.conf.sample %{buildroot}%{_sysconfdir}/keystone/logging.conf
install -p -D -m 640 etc/keystone-paste.ini %{buildroot}%{_sysconfdir}/keystone/keystone-paste.ini
install -p -D -m 640 etc/policy.json %{buildroot}%{_sysconfdir}/keystone/policy.json
install -p -D -m 640 etc/default_catalog.templates %{buildroot}%{_sysconfdir}/keystone/default_catalog.templates
install -p -D -m 640 etc/sso_callback_template.html %{buildroot}%{_sysconfdir}/keystone/sso_callback_template.html
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/openstack-keystone
install -p -D -m 644 etc/policy.v3cloudsample.json %{buildroot}%{_datadir}/keystone/policy.v3cloudsample.json
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysctl.d/openstack-keystone.conf
install -p -D -m 644 doc/build/man/*.1 %{buildroot}%{_mandir}/man1/
# Install sample data script.
install -p -D -m 755 tools/sample_data.sh %{buildroot}%{_datadir}/keystone/sample_data.sh
# Install apache configuration files
install -p -D -m 644 httpd/wsgi-keystone.conf  %{buildroot}%{_datadir}/keystone/

%pre
%openstack_pre_user_group_create keystone keystone /sbin/nologin
exit 0

%check
# TODO (IgorYozhikov) on a high amount of vCpu unit tests are not passing
# Since that we are launching tests in 1 by 1 mode by pack of 4
export TEST_RUN_CONCURRENCY=4
# don't want to depend on hacking for package building
rm keystone/tests/unit/test_hacking_checks.py
%{__python2} setup.py testr

%post
%tmpfiles_create %{_tmpfilesdir}/keystone.conf
%sysctl_apply openstack-keystone.conf

%files
%license LICENSE
%doc README.rst
%{_mandir}/man1/keystone*.1.gz
%{_bindir}/keystone-wsgi-admin
%{_bindir}/keystone-wsgi-public
%{_bindir}/keystone-manage
%_tmpfilesdir/keystone.conf
%dir %{_datadir}/keystone
%attr(0644, root, keystone) %{_datadir}/keystone/policy.v3cloudsample.json
%attr(0755, root, root) %{_datadir}/keystone/sample_data.sh
%attr(0644, root, keystone) %{_datadir}/keystone/wsgi-keystone.conf
%dir %attr(0750, root, keystone) %{_sysconfdir}/keystone/
%dir %attr(0750, root, keystone) %{_sysconfdir}/keystone/keystone.conf.d/
%{_sysconfdir}/keystone/README.config
%config(noreplace) %attr(0640, root, keystone) %{_sysconfdir}/keystone/keystone.conf
%config(noreplace) %attr(0640, root, keystone) %{_sysconfdir}/keystone/keystone.conf.d/010-keystone.conf
%config(noreplace) %attr(0640, root, keystone) %{_sysconfdir}/keystone/keystone-paste.ini
%config(noreplace) %attr(0640, root, keystone) %{_sysconfdir}/keystone/logging.conf
%config(noreplace) %attr(0640, root, keystone) %{_sysconfdir}/keystone/default_catalog.templates
%config(noreplace) %attr(0640, keystone, keystone) %{_sysconfdir}/keystone/policy.json
%config(noreplace) %attr(0640, keystone, keystone) %{_sysconfdir}/keystone/sso_callback_template.html
%config(noreplace) %{_sysconfdir}/logrotate.d/openstack-keystone
%dir %attr(0755, %{keystone}, %{keystone}) %{_localstatedir}/lib/keystone
%dir %attr(0750, %{keystone}, %{keystone}) %{_localstatedir}/log/keystone
%dir %attr(0750, %{keystone}, %{keystone}) %{_localstatedir}/cache/keystone
%{_sysconfdir}/sysctl.d/openstack-keystone.conf

%files -n python-keystone
%defattr(-,root,root,-)
%doc README.rst
%license LICENSE
%{python2_sitelib}/keystone*
%{python2_sitelib}/keystone-*.egg-info

%if 0%{?with_doc}
%files doc
%license LICENSE
%doc doc/build/html
%endif

%changelog
